##########################################################
## Analysis of herbaceous community by functional group ##

library(lme4)
library(lmerTest)
library(lsmeans)
library(multcomp)
library(plyr)
library(psych)

setwd("~/Library/Mobile Documents/com~apple~CloudDocs/Purdue PC/Honeysuckle Project/Forests Submission/Supplementary Materials/Data")
herb.grp<-read.table("Grouped Herb Cover.csv", header=T, sep=',', nrows=288)

herb.grp$Treatment<-factor(herb.grp$Treatment,levels(herb.grp$Treatment)[c(5,1,2,3,4)])
herb.grp$Removal<-factor(herb.grp$Removal, levels(herb.grp$Removal)[c(3,1,2)])
herb.grp$Mulch<-factor(herb.grp$Mulch, levels(herb.grp$Mulch)[c(2,3,1)])

herb.grp15<-subset(herb.grp, herb.grp$Year=="0")
herb.grp16<-subset(herb.grp, herb.grp$Year=="1")
herb.grp17<-subset(herb.grp, herb.grp$Year=="2")



ave.ann.15<-aggregate(herb.grp15$Annual.Native~herb.grp15$Treatment, FUN = mean)
ave.bi.15<-aggregate(herb.grp15$Biennial.Native~herb.grp15$Treatment, FUN = mean)
ave.per.15<-aggregate(herb.grp15$Perennial.Native~herb.grp15$Treatment, FUN = mean)
ave.vin.15<-aggregate(herb.grp15$Native.Vine~herb.grp15$Treatment, FUN = mean)
ave.gram.15<-aggregate(herb.grp15$Graminoid~herb.grp15$Treatment, FUN = mean)
ave.ext.15<-aggregate(herb.grp15$Exotic~herb.grp15$Treatment, FUN = mean)
ave.unk.15<-aggregate(herb.grp15$Unknown~herb.grp15$Treatment, FUN = mean)

ave.ann.16<-aggregate(herb.grp16$Annual.Native~herb.grp16$Treatment, FUN = mean)
ave.bi.16<-aggregate(herb.grp16$Biennial.Native~herb.grp16$Treatment, FUN = mean)
ave.per.16<-aggregate(herb.grp16$Perennial.Native~herb.grp16$Treatment, FUN = mean)
ave.vin.16<-aggregate(herb.grp16$Native.Vine~herb.grp16$Treatment, FUN = mean)
ave.gram.16<-aggregate(herb.grp16$Graminoid~herb.grp16$Treatment, FUN = mean)
ave.ext.16<-aggregate(herb.grp16$Exotic~herb.grp16$Treatment, FUN = mean)
ave.unk.16<-aggregate(herb.grp16$Unknown~herb.grp16$Treatment, FUN = mean)

ave.ann.17<-aggregate(herb.grp17$Annual.Native~herb.grp17$Treatment, FUN = mean)
ave.bi.17<-aggregate(herb.grp17$Biennial.Native~herb.grp17$Treatment, FUN = mean)
ave.per.17<-aggregate(herb.grp17$Perennial.Native~herb.grp17$Treatment, FUN = mean)
ave.vin.17<-aggregate(herb.grp17$Native.Vine~herb.grp17$Treatment, FUN = mean)
ave.gram.17<-aggregate(herb.grp17$Graminoid~herb.grp17$Treatment, FUN = mean)
ave.ext.17<-aggregate(herb.grp17$Exotic~herb.grp17$Treatment, FUN = mean)
ave.unk.17<-aggregate(herb.grp17$Unknown~herb.grp17$Treatment, FUN = mean)


#####################################################
### Linear mixed models for differences in groups ###
par(mfrow=c(1,1))
contrast.matrix <- rbind("Year:Ref vs. 0" = c(0, 1, 0, 0, 0, 0, 0, 0, 0, 0),
                        "Year:Ref vs. Year:Cut (no mulch)" =  c(0, 0, 0, 0, 0, -1, 1, 0, 0, 0),
                        "Year:Ref vs. Year:Fecon (mulch)" =  c(0, 0, 0, 0, 0, -1, 0, 0, 1, 0),
                        "Year:NoMulch vs. Year:Mulch" =  c(0, 0, 0, 0, 0, 0, -0.5, 0.5, -0.5, 0.5),
                        "Year:Cut vs. Year:Fecon" =  c(0, 0, 0, 0, 0, 0, -0.5, -0.5, 0.5, 0.5),
                        "Year:Cut- vs Year:Fecon+"=c(0,0,0,0,0, 0, -1, 0, 0, 1))

attach(herb.grp)

## Annuals ##
lm.ann.log<-lmer(log(Annual.Native+1)~Year*Treatment+(Year|Site:Plot)+(1|Site))
  plot(lm.ann.log) #need to remove severe outlier?
  hist(residuals(lm.ann.log))
  summary(lm.ann.log)

        anova(lm.ann.log)
        summary(glht(lm.ann.log,contrast.matrix))
    
## Biennials ##       
lm.bien.log<-lmer(log(Biennial.Native+1)~Year*Treatment+(Year|Site:Plot)+(1|Site))
  plot(lm.bien.log) 
  hist(residuals(lm.bien.log))
    
    anova(lm.bien.log) #Year:Treatment p=0.03
    summary(glht(lm.bien.log,contrast.matrix)) #no sig comparisons

## Perennials ##
lm.per.log<-lmer(log(Perennial.Native+1)~Year*Treatment+(Year|Site:Plot)+(1|Site))
  plot(lm.per.log) 
  hist(residuals(lm.per.log))
    anova(lm.per.log)
    #summary(lm.per.log)
    summary(glht(lm.per.log,contrast.matrix)) #Fecon- > Ref (p=0.03)

## Vines ##
lm.vin.log<-lmer(log(Native.Vine+1)~Year*Treatment+(Year|Site:Plot)+(1|Site))
  plot(lm.vin.log) 
  hist(residuals(lm.vin.log))
    anova(lm.vin.log)
      
    summary(glht(lm.vin.log,contrast.matrix)) 

## Graminoids ##    
lm.gram<-lmer(Graminoid~Year*Treatment+(1+Year|Site:Plot))
lm.gram.log<-lmer(log(Graminoid+1)~Year*Treatment+(1+Year|Site:Plot))
  plot(lm.gram.log) 
  hist(residuals(lm.gram.log))
    anova(lm.gram.log)
  
    summary(glht(lm.gram.log,contrast.matrix)) #graminoids increased more in Fecon plots than Cut plots
    summary(glht(lm.gram,contrast.matrix)) 
 
## Exotics ##       
lm.exot.log<-lmer(log(Exotic+1)~Year*Treatment+(1+Year|Site:Plot))
  plot(lm.exot.log) 
  hist(residuals(lm.exot.log))
    anova(lm.exot.log)

    summary(glht(lm.exot.log,contrast.matrix))



