### Analysis of honeysuckle cover in lower (< 1m; "herb-layer") ###
### and upper (1-5 m; "midstory") strata ###

library(lme4)
library(lmerTest)
library(psych)
library(multcomp)
library(lsmeans)
library(plyr)

setwd("~/Library/Mobile Documents/com~apple~CloudDocs/Purdue PC/Honeysuckle Project/Forests Submission/Supplementary Materials/Data")

HS.cover<-read.table("Honeysuckle Cover and Seedling Counts.csv", sep=',', header=T)

  HS.cover$Treatment<-factor(HS.cover$Treatment,levels(HS.cover$Treatment)[c(5,1,2,3,4)])
  HS.cover$Year.rel=HS.cover$Year-2015


HS.und.15<-subset(HS.cover, HS.cover$Year=="2015")
HS.und.16<-subset(HS.cover, HS.cover$Year=="2016")
HS.und.17<-subset(HS.cover, HS.cover$Year=="2017")

HS.mid.15<-subset(HS.cover, HS.cover$Year=="2015")
HS.mid.16<-subset(HS.cover, HS.cover$Year=="2016")
HS.mid.17<-subset(HS.cover, HS.cover$Year=="2017")

nrow(HS.und.15)

describeBy(HS.und.15$HerbLayerCover, group = NULL)
describeBy(HS.und.15$HerbLayerCover, HS.und.15$Site)

describeBy(HS.und.15$HerbLayerCover, HS.und.15$Treatment)
describeBy(HS.und.16$HerbLayerCover, HS.und.16$Treatment)
describeBy(HS.und.17$HerbLayerCover, HS.und.17$Treatment)

describeBy(HS.und.17$HerbLayerCover-HS.und.15$HerbLayerCover, HS.und.17$Treatment)
describeBy(HS.und.16$HerbLayerCover-HS.und.15$HerbLayerCover, HS.und.17$Treatment)
    describeBy(HS.und.16$HerbLayerCover, HS.und.17$Removal)$Cut[,"mean"]/ describeBy(HS.und.16$HerbLayerCover, HS.und.17$Removal)$Fecon[,"mean"]
    describeBy(HS.und.15$HerbLayerCover, HS.und.15$Removal)$Cut[,"mean"]/ describeBy(HS.und.15$HerbLayerCover, HS.und.15$Removal)$Fecon[,"mean"]
    

describeBy(HS.und.15$MidstoryCover, group = NULL)
describeBy(HS.und.15$MidstoryCover, HS.und.15$Site)
describeBy(HS.und.15$MidstoryCover, HS.und.15$Treatment)
describeBy(HS.und.16$MidstoryCover, HS.und.16$Treatment)
describeBy(HS.und.17$MidstoryCover, HS.und.17$Treatment)

describeBy((HS.und.17$MidstoryCover-HS.und.15$MidstoryCover), HS.und.17$Treatment)
describeBy((HS.und.16$MidstoryCover-HS.und.15$MidstoryCover), HS.und.17$Treatment)


### Linear models within year and of change values
contrast.matrix1 <- rbind("Ref vs. Cut-" =  c(0, 1, 0, 0, 0),
                          "Ref vs. Fecon+" =  c(0, 0, 0, 0, 1),
                         "Year:Unmulched vs Year:Mulched"=c(0,-0.5,0.5,-0.5,0.5),
                         "Year:Cut vs Year:Fecon"=c(0,-0.5,-0.5,0.5,0.5),
                         "Year:Cut- vs. Year:Fecon+" =  c(0, -1, 0, 0, 1))


attach(HS.und.15)
lm.und15<-lmer(HerbLayerCover~Treatment+(1|Site))
plot(lm.und15)
hist(residuals(lm.und15))

anova(lm.und15)
summary(glht(lm.und15, contrast.matrix1))

lm.mid15<-lmer(MidstoryCover~Treatment+(1|Site))
  plot(lm.mid15)
  hist(residuals(lm.mid15))
  
  anova(lm.mid15)
  summary(glht(lm.mid15, contrast.matrix1))
  
  lm.mid1516<-lmer((HS.und.16$MidstoryCover-MidstoryCover)~Treatment+(1|Site))
    plot(lm.mid1516)
    hist(residuals(lm.mid1516))
  
      anova(lm.mid1516)
      summary(glht(lm.mid1516, contrast.matrix1))
      
  lm.mid1517<-lmer((HS.und.17$MidstoryCover-MidstoryCover)~Treatment+(1|Site))
    plot(lm.mid1517)
    hist(residuals(lm.mid1517))
      
      anova(lm.mid1517)
      summary(glht(lm.mid1517, contrast.matrix1))
      
# summary(glht(lm.mid15, Treatment="Tukey"))

lm.und1516<-lmer(HS.und.16$HerbLayerCover-HerbLayerCover~Treatment+(1|Site))
  plot(lm.und1516)
  hist(residuals(lm.und1516))

  anova(lm.und1516)
  summary(glht(lm.und1516, contrast.matrix1))
  
  
lm.und1517<-lmer((HS.und.17$HerbLayerCover-HerbLayerCover)~Treatment+(1|Site))
  plot(lm.und1517)
  hist(residuals(lm.und1517))
  
  anova(lm.und1517)  
  summary(glht(lm.und1517, contrast.matrix1))
  
detach(HS.und.15)
attach(HS.und.16)

lm.und16<-lmer(HerbLayerCover~Treatment+(1|Site))
plot(lm.und16)

lm.und16.log<-lmer(log(HerbLayerCover+1)~Treatment+(1|Site))


plot(lm.und16.log)
hist(residuals(lm.und16.log))

anova(lm.und16.log)
summary(glht(lm.und16.log, mcp(Treatment="Tukey")))
summary(glht(lm.und16.log, contrast.matrix1))

lm.mid16<-lmer(MidstoryCover~Treatment+(1|Site))
plot(lm.mid16)

lm.mid16.log<-lmer(log(MidstoryCover+1)~Treatment+(1|Site))
plot(lm.mid16.log)
hist(residuals(lm.mid16.log))

anova(lm.mid16.log)
summary(glht(lm.mid16.log, mcp(Treatment="Tukey")))

detach(HS.und.16)
attach(HS.und.17)
lm.und17<-lmer(HerbLayerCover~Treatment+(1|Site))
plot(lm.und17)
hist(residuals(lm.und17))

anova(lm.und17)
summary(glht(lm.und17, mcp(Treatment="Tukey")))

lm.mid17<-lmer(MidstoryCover~Treatment+(1|Site))
plot(lm.mid17)

lm.mid17.log<-lmer(log(MidstoryCover+1)~Treatment+(1|Site))
plot(lm.mid17.log)
hist(residuals(lm.mid17.log))

anova(lm.mid17.log)
summary(glht(lm.mid17.log, mcp(Treatment="Tukey")))


detach(HS.und.17)


contrast.matrix <- rbind("Year:Ref vs. 0" = c(0, 1, 0, 0, 0, 0, 0, 0, 0, 0),
                         "Year:Ref vs. Year:Cut-" =  c(0, 0, 0, 0, 0, 0, 1, 0, 0, 0),
                         "Year:Ref vs. Year:Fecon+" =  c(0, 0, 0, 0, 0, 0, 0, 0, 0, 1),
                         "Year:Unmulched vs Year:Mulched"=c(0,0,0,0,0,0,-0.5,0.5,-0.5,0.5),
                         "Year:Cut vs Year:Fecon"=c(0,0,0,0,0,0,-0.5,-0.5,0.5,0.5),
                         "Year:Cut- vs. Year:Fecon+" =  c(0, 0, 0, 0, 0, 0, -1, 0, 0, 1))


attach(HS.cover)  
lm.hs.und<-lmer(sqrt(HerbLayerCover+0.5)~Year.rel*Treatment+(Year.rel|Site:Plot)+(1|Site))
plot(lm.hs.und)
hist(residuals(lm.hs.und))
anova(lm.hs.und)
summary(lm.hs.und)

summary(glht(lm.hs.und,contrast.matrix))

lm.hs.mid<-lmer(MidstoryCover~Year.rel*Treatment+(Year.rel|Site:Plot)+(1|Site))
plot(lm.hs.mid)
hist(residuals(lm.hs.mid))
anova(lm.hs.mid)
summary(lm.hs.mid)

summary(glht(lm.hs.mid,contrast.matrix))  

