## Densities of "sapling" sized ( > 5 cm dbh) honeysuckle shrubs ##

require(lme4)  
require(lmerTest)
require(multcomp)
require(psych)
  
setwd("~/Library/Mobile Documents/com~apple~CloudDocs/Purdue PC/Honeysuckle Project/Forests Submission/Supplementary Materials/Data")
  HS.density<-read.table("Honeysuckle Sapling Densities.csv", header=T, sep=',')
  trt.assign<-read.table("Treatment Assignments.csv", sep=",", header=T)


HS.den<-merge.data.frame(HS.density, trt.assign, by= "Plot")
#densities are saplings per ha

HS.den$Treatment.y<-factor(HS.den$Treatment.y, levels(HS.den$Treatment.y)[c(5,1,2,3,4)])
  levels(HS.den$Treatment.y) #ref should be first

attach(HS.den)
  head(HS.den)
boxplot(SMALL~Year+Treatment.x)
boxplot(ALL~Year+Treatment.x)

HS.15<-subset(HS.den, Year=="2015")
HS.16<-subset(HS.den, Year=="2016")
HS.17<-subset(HS.den, Year=="2017")

describeBy(HS.15)
describeBy(HS.15, group = HS.15$Site.x)
describeBy(HS.15,group = HS.15$Treatment.x)
describeBy(HS.16,group = HS.15$Treatment.x)
describeBy(HS.17,group = HS.15$Treatment.x)



contrast.matrix<- rbind("Ref vs 0"=c(0,1,0,0,0,0,0,0,0,0),
                        "Ref vs Cut-" = c(0,0,0,0,0,0,1,0,0,0),
                        "Ref vs Fecon+" = c(0,0,0,0,0,0,0,0,0,1),
                        "Cut vs. Fecon" = c(0,0,0,0,0,0, -0.5,-0.5,0.5,0.5))


lm.ALL<-lmer(ALL~Year.rel*Treatment.y+(Year.rel|Site.x:Plot)+(1|Site.x))
  plot(lm.ALL)
  hist(residuals(lm.ALL))
  
  anova(lm.ALL)
  summary(lm.ALL)
  summary(glht(lm.ALL,contrast.matrix))
  
  
  
allHS.means <- data.frame(matrix(vector(), 3, 3, 
                                 dimnames=list(c(), c("2015", "2016", "2017"))),
                          stringsAsFactors=F)   #create an empty table for means
  
  rownames(allHS.means)<-c("Ref","Cut","Fecon")
  
  
  allHS.means[,1]<-c(describeBy(HS.15,group="Treatment.x")$`Ref`["ALL","mean"],
                   describeBy(HS.15,group="Treatment.x")$`Cut`["ALL","mean"],
                   describeBy(HS.15,group="Treatment.x")$`Fecon`["ALL","mean"])
  allHS.means[,2]<-c(describeBy(HS.16,group="Treatment.x")$`Ref`["ALL","mean"],
                   describeBy(HS.16,group="Treatment.x")$`Cut`["ALL","mean"],
                   describeBy(HS.16,group="Treatment.x")$`Fecon`["ALL","mean"])
  allHS.means[,3]<-c(describeBy(HS.17,group="Treatment.x")$`Ref`["ALL","mean"],
                   describeBy(HS.17,group="Treatment.x")$`Cut`["ALL","mean"],
                   describeBy(HS.17,group="Treatment.x")$`Fecon`["ALL","mean"])
  
  allHS.means
  
  
allHS.se <- data.frame(matrix(vector(), 3, 3, 
                              dimnames=list(c(), c("2015", "2016", "2017"))),
                       stringsAsFactors=F)   #create an empty table for se
  
  rownames(allHS.se)<-c("Ref","Cut","Fecon")
  
  
  allHS.se[,1]<-c(describeBy(HS.15,group="Treatment.x")$`Ref`["ALL","se"],
                describeBy(HS.15,group="Treatment.x")$`Cut`["ALL","se"],
                describeBy(HS.15,group="Treatment.x")$`Fecon`["ALL","se"])
  allHS.se[,2]<-c(describeBy(HS.16,group="Treatment.x")$`Ref`["ALL","se"],
                describeBy(HS.16,group="Treatment.x")$`Cut`["ALL","se"],
                describeBy(HS.16,group="Treatment.x")$`Fecon`["ALL","se"])
  allHS.se[,3]<-c(describeBy(HS.17,group="Treatment.x")$`Ref`["ALL","se"],
                describeBy(HS.17,group="Treatment.x")$`Cut`["ALL","se"],
                describeBy(HS.17,group="Treatment.x")$`Fecon`["ALL","se"])
  
  allHS.se
  