### Analysis of spring ephemeral cover and diversity indices ###
### spring perennials defined as native perennial species that complete their flowering cycle from
### Apr-Jun, as listed by Kay Yaskevic

setwd("~/Library/Mobile Documents/com~apple~CloudDocs/Purdue PC/Honeysuckle Project/Forests Submission/Supplementary Materials/Data")

library(lme4)
library(lmerTest)
library(lsmeans)
library(multcomp)
library(psych)
library(vegan)

spring.mat<-read.table('Spring Perennials Cover Values.csv', header=T, sep=',')

head(spring.mat)
nrow(spring.mat)   #should = 288
ncol(spring.mat)  #33 columns (27 species)

spring.mat$Mulch<-factor(spring.mat$Mulch, levels(spring.mat$Mulch)[c(2,1,3)])
  levels(spring.mat$Mulch) #ref should be first
spring.mat$Treatment<-factor(spring.mat$Treatment, levels(spring.mat$Treatment)[c(5,1,2,3,4)])
  levels(spring.mat$Treatment) #ref should be first
spring.mat$Removal<-factor(spring.mat$Removal, levels(spring.mat$Removal)[c(3,1,2)])
  levels(spring.mat$Removal) #ref should be first

ncol(spring.mat)
spring.means<-matrix(data=NA,nrow=(33-6), ncol=15)
  colnames(spring.means)<-c("Ref15","Ref16","Ref17","Cut-15","Cut-16","Cut-17",
                          "Cut+15","Cut+16","Cut+17","Fecon-15","Fecon-16","Fecon-17","Fecon+15","Fecon+16","Fecon+17")
  rownames(spring.means)<-colnames(spring.mat)[7:33]
  for(i in 1:nrow(spring.means)){
    spring.means[i,]<-describeBy(spring.mat[,i+6],group = list(spring.mat$Year,spring.mat$Treatment),mat=T)$mean
    
  }
  options(max.print = 10000)
  spring.means
  
  spring.SE<-matrix(data=NA,nrow=(33-6), ncol=15)
  colnames(spring.SE)<-c("Ref15","Ref16","Ref17","Cut-15","Cut-16","Cut-17",
                       "Cut+15","Cut+16","Cut+17","Fecon-15","Fecon-16","Fecon-17","Fecon+15","Fecon+16","Fecon+17")
  rownames(spring.SE)<-colnames(spring.mat)[7:33]
  for(i in 1:nrow(spring.SE)){
    spring.SE[i,]<-describeBy(spring.mat[,i+6],group = list(spring.mat$Year,spring.mat$Treatment),mat=T)$se
    
  }
  options(max.print = 10000)
  spring.SE    
  
  
  
spring.15<-subset(spring.mat, spring.mat$Year=="2015")
  nrow(spring.15)
spring.16<-subset(spring.mat, spring.mat$Year=="2016")
  nrow(spring.16)
spring.17<-subset(spring.mat, spring.mat$Year=="2017")
  nrow(spring.17)  
  

### Total Cover Across All Years ###
  
totals.all<-cbind(spring.mat[,1:6],rowSums(spring.mat[,7:33]))
  colnames(totals.all)<-c("Plot","Site","Year","Treatment","Mulch","Removal","Tot.Cov")
  totals.all$Year.rel<-totals.all$Year-2015
  
  
  totals.15<-subset(totals.all, totals.all$Year=="2015")
    nrow(totals.15)
    describeBy(totals.15[which(totals.15$Treatment!="Ref"),], group=totals.15$Site[which(totals.15$Treatment!="Ref")])
  totals.16<-subset(totals.all, totals.all$Year=="2016")
    nrow(totals.16)
  totals.17<-subset(totals.all, totals.all$Year=="2017")
    nrow(totals.17)
    
sum(spring.mat$Podopel)/sum(totals.all$Tot.Cov)
   hist(spring.mat$Podopel/totals.all$Tot.Cov)
   
   sum(ifelse(spring.17$Podopel>0,1,0))
   Podopel.pres<-subset(spring.17, spring.17$Podopel>0)
      mean(Podopel.pres$Podopel/rowSums(Podopel.pres[,7:33]))
      sd(Podopel.pres$Podopel/rowSums(Podopel.pres[,7:33]))/sqrt(length(Podopel.pres$Podopel))
      
      
contrast.matrix<- rbind("Year:Ref vs. 0"=c(0,1,0,0,0,0,0,0,0,0),
                             "Year:Ref vs. Year:Cut-"=c(0, 0, 0, 0, 0, 0, 1, 0, 0, 0),
                             "Year:Ref vs. Year:Fecon+"=c(0, 0, 0, 0, 0, 0, 0, 0, 0, 1),
                             "Year:Cut vs Year:Fecon" = c(0, 0, 0, 0, 0, 0, -0.5, -0.5, 0.5, 0.5),
                             "Year:Unmulched vs Year:Mulched" = c(0, 0, 0, 0, 0, 0, -0.5, 0.5, -0.5, 0.5),
                             "Year:Cut- vs Year:Fecon+" = c(0, 0, 0, 0, 0, 0, -1, 0, 0, 1))
    
    
attach(totals.all)

  lm.tot<-lmer(Tot.Cov~Year.rel*Treatment+(Year.rel|Site:Plot)+(1|Site))
    plot(lm.tot)
    hist(residuals(lm.tot))
    lm.tot.log<-lmer(log(Tot.Cov+1)~Year.rel*Treatment+(Year.rel|Site:Plot)+(1|Site))
    plot(lm.tot.log)
    hist(residuals(lm.tot.log))
    
    anova(lm.tot.log)  #Year:Treatment
    
detach (totals.all) 
    
tot.means <- data.frame(matrix(vector(), 5, 3, 
                                   dimnames=list(c(), c("2015", "2016", "2017"))),
                            stringsAsFactors=F)   #create an empty table for means

    rownames(tot.means)<-c("Ref","Cut-","Cut+","Fecon-","Fecon+")
    
    
    tot.means[,1]<-c(describeBy(totals.15,group="Treatment")$`Ref`["Tot.Cov","mean"],
                     describeBy(totals.15,group="Treatment")$`Cut-`["Tot.Cov","mean"],
                     describeBy(totals.15,group="Treatment")$`Cut+`["Tot.Cov","mean"],
                     describeBy(totals.15,group="Treatment")$`Fecon-`["Tot.Cov","mean"],
                     describeBy(totals.15,group="Treatment")$`Fecon+`["Tot.Cov","mean"])
    tot.means[,2]<-c(describeBy(totals.16,group="Treatment")$`Ref`["Tot.Cov","mean"],
                     describeBy(totals.16,group="Treatment")$`Cut-`["Tot.Cov","mean"],
                     describeBy(totals.16,group="Treatment")$`Cut+`["Tot.Cov","mean"],
                     describeBy(totals.16,group="Treatment")$`Fecon-`["Tot.Cov","mean"],
                     describeBy(totals.16,group="Treatment")$`Fecon+`["Tot.Cov","mean"])
    tot.means[,3]<-c(describeBy(totals.17,group="Treatment")$`Ref`["Tot.Cov","mean"],
                     describeBy(totals.17,group="Treatment")$`Cut-`["Tot.Cov","mean"],
                     describeBy(totals.17,group="Treatment")$`Cut+`["Tot.Cov","mean"],
                     describeBy(totals.17,group="Treatment")$`Fecon-`["Tot.Cov","mean"],
                     describeBy(totals.17,group="Treatment")$`Fecon+`["Tot.Cov","mean"])
    
    tot.means
    
    
    tot.se <- data.frame(matrix(vector(), 5, 3, 
                                   dimnames=list(c(), c("2015", "2016", "2017"))),
                            stringsAsFactors=F)   #create an empty table for se
    
    rownames(tot.se)<-c("Ref","Cut-","Cut+","Fecon-","Fecon+")
    
    
    tot.se[,1]<-c(describeBy(totals.15,group="Treatment")$`Ref`["Tot.Cov","se"],
                     describeBy(totals.15,group="Treatment")$`Cut-`["Tot.Cov","se"],
                     describeBy(totals.15,group="Treatment")$`Cut+`["Tot.Cov","se"],
                     describeBy(totals.15,group="Treatment")$`Fecon-`["Tot.Cov","se"],
                     describeBy(totals.15,group="Treatment")$`Fecon+`["Tot.Cov","se"])
    tot.se[,2]<-c(describeBy(totals.16,group="Treatment")$`Ref`["Tot.Cov","se"],
                     describeBy(totals.16,group="Treatment")$`Cut-`["Tot.Cov","se"],
                     describeBy(totals.16,group="Treatment")$`Cut+`["Tot.Cov","se"],
                     describeBy(totals.16,group="Treatment")$`Fecon-`["Tot.Cov","se"],
                     describeBy(totals.16,group="Treatment")$`Fecon+`["Tot.Cov","se"])
    tot.se[,3]<-c(describeBy(totals.17,group="Treatment")$`Ref`["Tot.Cov","se"],
                     describeBy(totals.17,group="Treatment")$`Cut-`["Tot.Cov","se"],
                     describeBy(totals.17,group="Treatment")$`Cut+`["Tot.Cov","se"],
                     describeBy(totals.17,group="Treatment")$`Fecon-`["Tot.Cov","se"],
                     describeBy(totals.17,group="Treatment")$`Fecon+`["Tot.Cov","se"])
    
    
plotsegraph <- function(loc, value, sterr, wiskwidth, color = "grey", linewidth = 1) {
      
      w <- wiskwidth/2
      segments(x0 = loc, x1 = loc, y0 = value - sterr, y1 = value + sterr, col = color, 
               lwd = linewidth)
      segments(x0 = loc - w, x1 = loc + w, y0 = value + sterr, y1 = value + sterr, 
               col = color, lwd = linewidth)  # upper whiskers
      segments(x0 = loc - w, x1 = loc + w, y0 = value - sterr, y1 = value - sterr, 
               col = color, lwd = linewidth)  # lower whiskers
    }
    m.15.rf<-tot.means[1,1]
    m.15.cn<-tot.means[2,1]
    m.15.cw<-tot.means[3,1]
    m.15.fn<-tot.means[4,1]
    m.15.fw<-tot.means[5,1]
    m.16.rf<-tot.means[1,2]
    m.16.cn<-tot.means[2,2]
    m.16.cw<-tot.means[3,2]
    m.16.fn<-tot.means[4,2]
    m.16.fw<-tot.means[5,2]
    m.17.rf<-tot.means[1,3]
    m.17.cn<-tot.means[2,3]
    m.17.cw<-tot.means[3,3]
    m.17.fn<-tot.means[4,3]
    m.17.fw<-tot.means[5,3]
    
    se.15.rf<-tot.se[1,1]
    se.15.cn<-tot.se[2,1]
    se.15.cw<-tot.se[3,1]
    se.15.fn<-tot.se[4,1]
    se.15.fw<-tot.se[5,1]
    se.16.rf<-tot.se[1,2]
    se.16.cn<-tot.se[2,2]
    se.16.cw<-tot.se[3,2]
    se.16.fn<-tot.se[4,2]
    se.16.fw<-tot.se[5,2]
    se.17.rf<-tot.se[1,3]
    se.17.cn<-tot.se[2,3]
    se.17.cw<-tot.se[3,3]
    se.17.fn<-tot.se[4,3]
    se.17.fw<-tot.se[5,3]
    
    par(cex.main = 1.5, mar = c(5, 4, 4, 1) + 0.1, mgp = c(3.5, 1, 0), cex.lab = 1.5, 
        font.lab = 2, cex.axis = 1.3, bty = "n", las = 1)
    x1 <- c(1, 2, 3, 4)
plot(x1, c(-10, -10, -10, -10), type = "p", ylab = "", xlab = " ", cex = 1.5, 
         ylim = c(0, 7), xlim = c(1, 4), lwd = 2, pch = 5, axes = F, main = "")  #Total Spring Ephemeral Cover
    axis(1, at = c(1.5, 2.5, 3.5), labels = c("2015", "2016", "2017"))
    mtext("Year", side = 1, line = 3, cex = 1.5, font = 2)
    axis(2, pos = 1.2, seq(0,7,by=1), las=1)
    par(las = 0)
    mtext("Percent Cover", side = 2, line = 1.5, cex = 1.5, font = 2)
    x <- c(1.5, 2.5, 3.5)
    points(x, c(m.15.rf, m.16.rf, m.17.rf), cex = 2, lwd = 2, pch = 10)
    points(x+0.12, c(m.15.cn, m.16.cn, m.17.cn), cex = 2, lwd = 2, pch = 24) #col = colors()[c(593)]
    points(x+0.06, c(m.15.cw, m.16.cw, m.17.cw), cex = 2, lwd = 2, pch = 17) #,col=colors()[c(593)]
    points(x-0.12, c(m.15.fn, m.16.fn, m.17.fn), cex = 2, lwd = 2, pch = 23) #, col=colors()[c(55)]
    points(x-0.06, c(m.15.fw, m.16.fw, m.17.fw), cex = 2, lwd = 2, pch = 18) #, col=colors()[c(55)]
    
    lines(x, c(m.15.rf, m.16.rf, m.17.rf), lwd = 4, type = "c", lty=1,col=colors()[c(320)])
    lines(x+0.12, c(m.15.cn, m.16.cn, m.17.cn), lwd = 4, type = "c", lty=1) #,col=colors()[c(593)]
    lines(x+0.06, c(m.15.cw, m.16.cw, m.17.cw), lwd = 4, type = "c", lty=2) #,col=colors()[c(593)]
    lines(x-0.12, c(m.15.fn, m.16.fn, m.17.fn), lwd = 4, type = "c", lty=2) #, col=colors()[c(55)]
    lines(x-0.06, c(m.15.fw, m.16.fw, m.17.fw), lwd = 4, type = "c",lty=1) #, col=colors()[c(55)]
    
    plot.errbars <- plotsegraph(x, c(m.15.rf, m.16.rf, m.17.rf), 
                      c(se.15.rf, se.16.rf, se.17.rf), 0.1, color = "black")  #0.1 = wiskwidth
    plot.errbars <- plotsegraph(x+0.12, c(m.15.cn, m.16.cn, m.17.cn), 
                                c(se.15.cn, se.16.cn, se.17.cn), 0.1, color = "black")  #0.1 = wiskwidth
    plot.errbars <- plotsegraph(x+0.06, c(m.15.cw, m.16.cw, m.17.cw), 
                                c(se.15.cw, se.16.cw, se.17.cw), 0.1, color = "black")  #0.1 = wiskwidth
    plot.errbars <- plotsegraph(x-0.12, c(m.15.fn, m.16.fn, m.17.fn), 
                                c(se.15.fn, se.16.fn, se.17.fn), 0.1, color = "black")  #0.1 = wiskwidth
    plot.errbars <- plotsegraph(x-0.06, c(m.15.fw, m.16.fw, m.17.fw), 
                                c(se.15.fw, se.16.fw, se.17.fw), 0.1, color = "black")  #0.1 = wiskwidth
    
    #legend("topleft", pch=c(1,2,17,5,18), inset = c(0.2,0.1), col=colors()[c(24,593,593,55,55)],
    #      lty=c(1,1,2,2,1),
    #    legend=c("Reference","Cut w/o mulch", "Cut w/ mulch","Fecon w/o mulch", "Fecon w/ mulch"))
    

    
### Calculate Diversity Indices ###
    
spring15.sp<-spring.15[,7:33]
  S15<-as.vector(specnumber(spring15.sp, spring.15[,1]))
    S.15<-cbind(spring.15[,1:6],S15)
    colnames(S.15)[7]<-"S"
  H15<-as.vector(diversity(spring15.sp, index = "shannon"))
    H.15<-cbind(spring.15[,1:6],H15)
    colnames(H.15)[7]<-"H"
  J15<-H15/log(S15)
    J.15<-cbind(spring.15[,1:6],J15)    
    colnames(J.15)[7]<-"J"
    
spring16.sp<-spring.16[,7:33]
  S16<-as.vector(specnumber(spring16.sp, spring.16[,1]))
    S.16<-cbind(spring.16[,1:6],S16)
    colnames(S.16)[7]<-"S"
  H16<-as.vector(diversity(spring16.sp, index = "shannon"))
    H.16<-cbind(spring.16[,1:6],H16)
    colnames(H.16)[7]<-"H"
  J16<-H16/log(S16)    
    J.16<-cbind(spring.16[,1:6],J16)
    colnames(J.16)[7]<-"J"
    
spring17.sp<-spring.17[,7:33]
  S17<-as.vector(specnumber(spring17.sp, spring.17[,1]))
    S.17<-cbind(spring.17[,1:6],S17)
    colnames(S.17)[7]<-"S"
  H17<-as.vector(diversity(spring17.sp, index = "shannon"))
    H.17<-cbind(spring.17[,1:6],H17)
    colnames(H.17)[7]<-"H"
  J17<-H17/log(S17)    
    J.17<-cbind(spring.17[,1:6],J17)
    colnames(J.17)[7]<-"J"
    
    richness<-rbind(S.15,S.16,S.17)
    richness$Year.rel<-richness$Year-2015
    diversity<-rbind(H.15,H.16,H.17)
    diversity$Year.rel<-diversity$Year-2015
    evenness<-rbind(J.15, J.16, J.17)
    evenness$Year.rel<-evenness$Year-2015
    
    
### Line Graphs for diversity indices

### Richness
    S.means <- data.frame(matrix(vector(), 5, 3, 
                                   dimnames=list(c(), c("2015", "2016", "2017"))),
                            stringsAsFactors=F)   #create an empty table for means
    
    rownames(S.means)<-c("Ref","Cut-","Cut+","Fecon-","Fecon+")
    
    
    S.means[,1]<-c(describeBy(S.15,group="Treatment")$`Ref`["S","mean"],
                     describeBy(S.15,group="Treatment")$`Cut-`["S","mean"],
                     describeBy(S.15,group="Treatment")$`Cut+`["S","mean"],
                     describeBy(S.15,group="Treatment")$`Fecon-`["S","mean"],
                     describeBy(S.15,group="Treatment")$`Fecon+`["S","mean"])
    S.means[,2]<-c(describeBy(S.16,group="Treatment")$`Ref`["S","mean"],
                     describeBy(S.16,group="Treatment")$`Cut-`["S","mean"],
                     describeBy(S.16,group="Treatment")$`Cut+`["S","mean"],
                     describeBy(S.16,group="Treatment")$`Fecon-`["S","mean"],
                     describeBy(S.16,group="Treatment")$`Fecon+`["S","mean"])
    S.means[,3]<-c(describeBy(S.17,group="Treatment")$`Ref`["S","mean"],
                     describeBy(S.17,group="Treatment")$`Cut-`["S","mean"],
                     describeBy(S.17,group="Treatment")$`Cut+`["S","mean"],
                     describeBy(S.17,group="Treatment")$`Fecon-`["S","mean"],
                     describeBy(S.17,group="Treatment")$`Fecon+`["S","mean"])
    
    S.means
    
    
S.se <- data.frame(matrix(vector(), 5, 3, 
                                dimnames=list(c(), c("2015", "2016", "2017"))),
                         stringsAsFactors=F)   #create an empty table for se
    
    rownames(S.se)<-c("Ref","Cut-","Cut+","Fecon-","Fecon+")
    
    
    S.se[,1]<-c(describeBy(S.15,group="Treatment")$`Ref`["S","se"],
                  describeBy(S.15,group="Treatment")$`Cut-`["S","se"],
                  describeBy(S.15,group="Treatment")$`Cut+`["S","se"],
                  describeBy(S.15,group="Treatment")$`Fecon-`["S","se"],
                  describeBy(S.15,group="Treatment")$`Fecon+`["S","se"])
    S.se[,2]<-c(describeBy(S.16,group="Treatment")$`Ref`["S","se"],
                  describeBy(S.16,group="Treatment")$`Cut-`["S","se"],
                  describeBy(S.16,group="Treatment")$`Cut+`["S","se"],
                  describeBy(S.16,group="Treatment")$`Fecon-`["S","se"],
                  describeBy(S.16,group="Treatment")$`Fecon+`["S","se"])
    S.se[,3]<-c(describeBy(S.17,group="Treatment")$`Ref`["S","se"],
                  describeBy(S.17,group="Treatment")$`Cut-`["S","se"],
                  describeBy(S.17,group="Treatment")$`Cut+`["S","se"],
                  describeBy(S.17,group="Treatment")$`Fecon-`["S","se"],
                  describeBy(S.17,group="Treatment")$`Fecon+`["S","se"])
    
    S_m.15.rf<-S.means[1,1]
    S_m.15.cn<-S.means[2,1]
    S_m.15.cw<-S.means[3,1]
    S_m.15.fn<-S.means[4,1]
    S_m.15.fw<-S.means[5,1]
    S_m.16.rf<-S.means[1,2]
    S_m.16.cn<-S.means[2,2]
    S_m.16.cw<-S.means[3,2]
    S_m.16.fn<-S.means[4,2]
    S_m.16.fw<-S.means[5,2]
    S_m.17.rf<-S.means[1,3]
    S_m.17.cn<-S.means[2,3]
    S_m.17.cw<-S.means[3,3]
    S_m.17.fn<-S.means[4,3]
    S_m.17.fw<-S.means[5,3]
    
    S_se.15.rf<-S.se[1,1]
    S_se.15.cn<-S.se[2,1]
    S_se.15.cw<-S.se[3,1]
    S_se.15.fn<-S.se[4,1]
    S_se.15.fw<-S.se[5,1]
    S_se.16.rf<-S.se[1,2]
    S_se.16.cn<-S.se[2,2]
    S_se.16.cw<-S.se[3,2]
    S_se.16.fn<-S.se[4,2]
    S_se.16.fw<-S.se[5,2]
    S_se.17.rf<-S.se[1,3]
    S_se.17.cn<-S.se[2,3]
    S_se.17.cw<-S.se[3,3]
    S_se.17.fn<-S.se[4,3]
    S_se.17.fw<-S.se[5,3]
    
  par(cex.main = 1.5, mar = c(5, 4, 4, 1) + 0.1, mgp = c(3.5, 1, 0), cex.lab = 1.5, 
        font.lab = 2, cex.axis = 1.3, bty = "n", las = 1)
    x1 <- c(1, 2, 3, 4)
  plot(x1, c(-10, -10, -10, -10), type = "p", ylab = "", xlab = " ", cex = 1.5, 
         ylim = c(0, 6), xlim = c(1, 4), lwd = 2, pch = 5, axes = F, main = "")  #Richness
    axis(1, at = c(1.5, 2.5, 3.5), labels = c("2015", "2016", "2017"))
    mtext("Year", side = 1, line = 3, cex = 1.5, font = 2)
    axis(2, pos = 1.2, seq(0,6,by=1), las=1)
    par(las = 0)
    mtext("Richness (S)", side = 2, line = 1.5, cex = 1.5, font = 2)
    x <- c(1.5, 2.5, 3.5)
    
    points(x, c(S_m.15.rf, S_m.16.rf, S_m.17.rf), cex = 2, lwd = 2, pch = 10)
    points(x+0.12, c(S_m.15.cn, S_m.16.cn, S_m.17.cn), cex = 2, lwd = 2, pch = 24) #,col = colors()[c(593)]
    points(x+0.06, c(S_m.15.cw, S_m.16.cw, S_m.17.cw), cex = 2, lwd = 2, pch = 17) #,col=colors()[c(593)]
    points(x-0.12, c(S_m.15.fn, S_m.16.fn, S_m.17.fn), cex = 2, lwd = 2, pch = 23) #, col=colors()[c(55)]
    points(x-0.06, c(S_m.15.fw, S_m.16.fw, S_m.17.fw), cex = 2, lwd = 2, pch = 18) #, col=colors()[c(55)]
    
    lines(x, c(S_m.15.rf, S_m.16.rf, S_m.17.rf), lwd = 4, type = "c", lty=1,col=colors()[c(320)])
    lines(x+0.12, c(S_m.15.cn, S_m.16.cn, S_m.17.cn), lwd = 4, type = "c", lty=1) #,col=colors()[c(593)]
    lines(x+0.06, c(S_m.15.cw, S_m.16.cw, S_m.17.cw), lwd = 4, type = "c", lty=2) #,col=colors()[c(593)]
    lines(x-0.12, c(S_m.15.fn, S_m.16.fn, S_m.17.fn), lwd = 4, type = "c", lty=2) #, col=colors()[c(55)]
    lines(x-0.06, c(S_m.15.fw, S_m.16.fw, S_m.17.fw), lwd = 4, type = "c",lty=1) #, col=colors()[c(55)]
    
    plot.errbars <- plotsegraph(x, c(S_m.15.rf, S_m.16.rf, S_m.17.rf), 
                                c(S_se.15.rf, S_se.16.rf, S_se.17.rf), 0.1, color = "black")  #0.1 = wiskwidth
    plot.errbars <- plotsegraph(x+0.12, c(S_m.15.cn, S_m.16.cn, S_m.17.cn), 
                                c(S_se.15.cn, S_se.16.cn, S_se.17.cn), 0.1, color = "black")  #0.1 = wiskwidth
    plot.errbars <- plotsegraph(x+0.06, c(S_m.15.cw, S_m.16.cw, S_m.17.cw), 
                                c(S_se.15.cw, S_se.16.cw, S_se.17.cw), 0.1, color = "black")  #0.1 = wiskwidth
    plot.errbars <- plotsegraph(x-0.12, c(S_m.15.fn, S_m.16.fn, S_m.17.fn), 
                                c(S_se.15.fn, S_se.16.fn, S_se.17.fn), 0.1, color = "black")  #0.1 = wiskwidth
    plot.errbars <- plotsegraph(x-0.06, c(S_m.15.fw, S_m.16.fw, S_m.17.fw), 
                                c(S_se.15.fw, S_se.16.fw, S_se.17.fw), 0.1, color = "black")  #0.1 = wiskwidth
    
    #legend("topleft", pch=c(1,2,17,5,18), inset = c(0.2,0.1), col=colors()[c(24,593,593,55,55)],
    #      lty=c(1,1,2,2,1),
    #    legend=c("Reference","Cut w/o mulch", "Cut w/ mulch","Fecon w/o mulch", "Fecon w/ mulch"))
    
#### Diversity linegraph
  H.means <- data.frame(matrix(vector(), 5, 3, 
                                 dimnames=list(c(), c("2015", "2016", "2017"))),
                          stringsAsFactors=F)   #create an empty table for means
    
    rownames(H.means)<-c("Ref","Cut-","Cut+","Fecon-","Fecon+")
    
    
    H.means[,1]<-c(describeBy(H.15,group="Treatment")$`Ref`["H","mean"],
                   describeBy(H.15,group="Treatment")$`Cut-`["H","mean"],
                   describeBy(H.15,group="Treatment")$`Cut+`["H","mean"],
                   describeBy(H.15,group="Treatment")$`Fecon-`["H","mean"],
                   describeBy(H.15,group="Treatment")$`Fecon+`["H","mean"])
    H.means[,2]<-c(describeBy(H.16,group="Treatment")$`Ref`["H","mean"],
                   describeBy(H.16,group="Treatment")$`Cut-`["H","mean"],
                   describeBy(H.16,group="Treatment")$`Cut+`["H","mean"],
                   describeBy(H.16,group="Treatment")$`Fecon-`["H","mean"],
                   describeBy(H.16,group="Treatment")$`Fecon+`["H","mean"])
    H.means[,3]<-c(describeBy(H.17,group="Treatment")$`Ref`["H","mean"],
                   describeBy(H.17,group="Treatment")$`Cut-`["H","mean"],
                   describeBy(H.17,group="Treatment")$`Cut+`["H","mean"],
                   describeBy(H.17,group="Treatment")$`Fecon-`["H","mean"],
                   describeBy(H.17,group="Treatment")$`Fecon+`["H","mean"])
    
    H.means
    
    
    H.se <- data.frame(matrix(vector(), 5, 3, 
                              dimnames=list(c(), c("2015", "2016", "2017"))),
                       stringsAsFactors=F)   #create an empty table for se
    
    rownames(H.se)<-c("Ref","Cut-","Cut+","Fecon-","Fecon+")
    
    
    H.se[,1]<-c(describeBy(H.15,group="Treatment")$`Ref`["H","se"],
                describeBy(H.15,group="Treatment")$`Cut-`["H","se"],
                describeBy(H.15,group="Treatment")$`Cut+`["H","se"],
                describeBy(H.15,group="Treatment")$`Fecon-`["H","se"],
                describeBy(H.15,group="Treatment")$`Fecon+`["H","se"])
    H.se[,2]<-c(describeBy(H.16,group="Treatment")$`Ref`["H","se"],
                describeBy(H.16,group="Treatment")$`Cut-`["H","se"],
                describeBy(H.16,group="Treatment")$`Cut+`["H","se"],
                describeBy(H.16,group="Treatment")$`Fecon-`["H","se"],
                describeBy(H.16,group="Treatment")$`Fecon+`["H","se"])
    H.se[,3]<-c(describeBy(H.17,group="Treatment")$`Ref`["H","se"],
                describeBy(H.17,group="Treatment")$`Cut-`["H","se"],
                describeBy(H.17,group="Treatment")$`Cut+`["H","se"],
                describeBy(H.17,group="Treatment")$`Fecon-`["H","se"],
                describeBy(H.17,group="Treatment")$`Fecon+`["H","se"])
    
    H_m.15.rf<-H.means[1,1]
    H_m.15.cn<-H.means[2,1]
    H_m.15.cw<-H.means[3,1]
    H_m.15.fn<-H.means[4,1]
    H_m.15.fw<-H.means[5,1]
    H_m.16.rf<-H.means[1,2]
    H_m.16.cn<-H.means[2,2]
    H_m.16.cw<-H.means[3,2]
    H_m.16.fn<-H.means[4,2]
    H_m.16.fw<-H.means[5,2]
    H_m.17.rf<-H.means[1,3]
    H_m.17.cn<-H.means[2,3]
    H_m.17.cw<-H.means[3,3]
    H_m.17.fn<-H.means[4,3]
    H_m.17.fw<-H.means[5,3]
    
    H_se.15.rf<-H.se[1,1]
    H_se.15.cn<-H.se[2,1]
    H_se.15.cw<-H.se[3,1]
    H_se.15.fn<-H.se[4,1]
    H_se.15.fw<-H.se[5,1]
    H_se.16.rf<-H.se[1,2]
    H_se.16.cn<-H.se[2,2]
    H_se.16.cw<-H.se[3,2]
    H_se.16.fn<-H.se[4,2]
    H_se.16.fw<-H.se[5,2]
    H_se.17.rf<-H.se[1,3]
    H_se.17.cn<-H.se[2,3]
    H_se.17.cw<-H.se[3,3]
    H_se.17.fn<-H.se[4,3]
    H_se.17.fw<-H.se[5,3]
    
par(cex.main = 1.5, mar = c(5, 4, 4, 1) + 0.1, mgp = c(3.5, 1, 0), cex.lab = 1.5, 
        font.lab = 2, cex.axis = 1.3, bty = "n", las = 1)
    x1 <- c(1, 2, 3, 4)
plot(x1, c(-10, -10, -10, -10), type = "p", ylab = "", xlab = " ", cex = 1.5, 
         ylim = c(0, 1.2), xlim = c(1, 4), lwd = 2, pch = 5, axes = F, main = "")  #Richness
    axis(1, at = c(1.5, 2.5, 3.5), labels = c("2015", "2016", "2017"))
    mtext("Year", side = 1, line = 3, cex = 1.5, font = 2)
    axis(2, pos = 1.2, seq(0,1.2,by=0.2), las=1)
    par(las = 0)
    mtext("Diversity (H')", side = 2, line = 1.5, cex = 1.5, font = 2)
    x <- c(1.5, 2.5, 3.5)

    points(x, c(H_m.15.rf, H_m.16.rf, H_m.17.rf), cex = 2, lwd = 2, pch = 10)
    points(x+0.12, c(H_m.15.cn, H_m.16.cn, H_m.17.cn), cex = 2, lwd = 2, pch = 24) #,col = colors()[c(593)]
    points(x+0.06, c(H_m.15.cw, H_m.16.cw, H_m.17.cw), cex = 2, lwd = 2, pch = 17) #,col=colors()[c(593)]
    points(x-0.12, c(H_m.15.fn, H_m.16.fn, H_m.17.fn), cex = 2, lwd = 2, pch = 23) #, col=colors()[c(55)]
    points(x-0.06, c(H_m.15.fw, H_m.16.fw, H_m.17.fw), cex = 2, lwd = 2, pch = 18) #, col=colors()[c(55)]
    
    lines(x, c(H_m.15.rf, H_m.16.rf, H_m.17.rf), lwd = 4, type = "c", lty=1,col=colors()[c(320)])
    lines(x+0.12, c(H_m.15.cn, H_m.16.cn, H_m.17.cn), lwd = 4, type = "c", lty=1) #,col=colors()[c(593)]
    lines(x+0.06, c(H_m.15.cw, H_m.16.cw, H_m.17.cw), lwd = 4, type = "c", lty=2) #,col=colors()[c(593)]
    lines(x-0.12, c(H_m.15.fn, H_m.16.fn, H_m.17.fn), lwd = 4, type = "c", lty=2) #, col=colors()[c(55)]
    lines(x-0.06, c(H_m.15.fw, H_m.16.fw, H_m.17.fw), lwd = 4, type = "c",lty=1) #, col=colors()[c(55)]
    
    plot.errbars <- plotsegraph(x, c(H_m.15.rf, H_m.16.rf, H_m.17.rf), 
                                c(H_se.15.rf, H_se.16.rf, H_se.17.rf), 0.1, color = "black")  #0.1 = wiskwidth
    plot.errbars <- plotsegraph(x+0.12, c(H_m.15.cn, H_m.16.cn, H_m.17.cn), 
                                c(H_se.15.cn, H_se.16.cn, H_se.17.cn), 0.1, color = "black")  #0.1 = wiskwidth
    plot.errbars <- plotsegraph(x+0.06, c(H_m.15.cw, H_m.16.cw, H_m.17.cw), 
                                c(H_se.15.cw, H_se.16.cw, H_se.17.cw), 0.1, color = "black")  #0.1 = wiskwidth
    plot.errbars <- plotsegraph(x-0.12, c(H_m.15.fn, H_m.16.fn, H_m.17.fn), 
                                c(H_se.15.fn, H_se.16.fn, H_se.17.fn), 0.1, color = "black")  #0.1 = wiskwidth
    plot.errbars <- plotsegraph(x-0.06, c(H_m.15.fw, H_m.16.fw, H_m.17.fw), 
                                c(H_se.15.fw, H_se.16.fw, H_se.17.fw), 0.1, color = "black")  #0.1 = wiskwidth
    
    #legend("topleft", pch=c(1,2,17,5,18), inset = c(0.2,0.1), col=colors()[c(24,593,593,55,55)],
    #      lty=c(1,1,2,2,1),
    #    legend=c("Reference","Cut w/o mulch", "Cut w/ mulch","Fecon w/o mulch", "Fecon w/ mulch"))

### Evenness linegraph
    J.means <- data.frame(matrix(vector(), 5, 3, 
                                 dimnames=list(c(), c("2015", "2016", "2017"))),
                          stringsAsFactors=F)   #create an empty table for means
    
    rownames(J.means)<-c("Ref","Cut-","Cut+","Fecon-","Fecon+")
    
    
    J.means[,1]<-c(describeBy(J.15,group="Treatment")$`Ref`["J","mean"],
                   describeBy(J.15,group="Treatment")$`Cut-`["J","mean"],
                   describeBy(J.15,group="Treatment")$`Cut+`["J","mean"],
                   describeBy(J.15,group="Treatment")$`Fecon-`["J","mean"],
                   describeBy(J.15,group="Treatment")$`Fecon+`["J","mean"])
    J.means[,2]<-c(describeBy(J.16,group="Treatment")$`Ref`["J","mean"],
                   describeBy(J.16,group="Treatment")$`Cut-`["J","mean"],
                   describeBy(J.16,group="Treatment")$`Cut+`["J","mean"],
                   describeBy(J.16,group="Treatment")$`Fecon-`["J","mean"],
                   describeBy(J.16,group="Treatment")$`Fecon+`["J","mean"])
    J.means[,3]<-c(describeBy(J.17,group="Treatment")$`Ref`["J","mean"],
                   describeBy(J.17,group="Treatment")$`Cut-`["J","mean"],
                   describeBy(J.17,group="Treatment")$`Cut+`["J","mean"],
                   describeBy(J.17,group="Treatment")$`Fecon-`["J","mean"],
                   describeBy(J.17,group="Treatment")$`Fecon+`["J","mean"])
    
    J.means
    
    
    J.se <- data.frame(matrix(vector(), 5, 3, 
                              dimnames=list(c(), c("2015", "2016", "2017"))),
                       stringsAsFactors=F)   #create an empty table for se
    
    rownames(J.se)<-c("Ref","Cut-","Cut+","Fecon-","Fecon+")
    
    
    J.se[,1]<-c(describeBy(J.15,group="Treatment")$`Ref`["J","se"],
                describeBy(J.15,group="Treatment")$`Cut-`["J","se"],
                describeBy(J.15,group="Treatment")$`Cut+`["J","se"],
                describeBy(J.15,group="Treatment")$`Fecon-`["J","se"],
                describeBy(J.15,group="Treatment")$`Fecon+`["J","se"])
    J.se[,2]<-c(describeBy(J.16,group="Treatment")$`Ref`["J","se"],
                describeBy(J.16,group="Treatment")$`Cut-`["J","se"],
                describeBy(J.16,group="Treatment")$`Cut+`["J","se"],
                describeBy(J.16,group="Treatment")$`Fecon-`["J","se"],
                describeBy(J.16,group="Treatment")$`Fecon+`["J","se"])
    J.se[,3]<-c(describeBy(J.17,group="Treatment")$`Ref`["J","se"],
                describeBy(J.17,group="Treatment")$`Cut-`["J","se"],
                describeBy(J.17,group="Treatment")$`Cut+`["J","se"],
                describeBy(J.17,group="Treatment")$`Fecon-`["J","se"],
                describeBy(J.17,group="Treatment")$`Fecon+`["J","se"])
    
    J_m.15.rf<-J.means[1,1]
    J_m.15.cn<-J.means[2,1]
    J_m.15.cw<-J.means[3,1]
    J_m.15.fn<-J.means[4,1]
    J_m.15.fw<-J.means[5,1]
    J_m.16.rf<-J.means[1,2]
    J_m.16.cn<-J.means[2,2]
    J_m.16.cw<-J.means[3,2]
    J_m.16.fn<-J.means[4,2]
    J_m.16.fw<-J.means[5,2]
    J_m.17.rf<-J.means[1,3]
    J_m.17.cn<-J.means[2,3]
    J_m.17.cw<-J.means[3,3]
    J_m.17.fn<-J.means[4,3]
    J_m.17.fw<-J.means[5,3]
    
    J_se.15.rf<-J.se[1,1]
    J_se.15.cn<-J.se[2,1]
    J_se.15.cw<-J.se[3,1]
    J_se.15.fn<-J.se[4,1]
    J_se.15.fw<-J.se[5,1]
    J_se.16.rf<-J.se[1,2]
    J_se.16.cn<-J.se[2,2]
    J_se.16.cw<-J.se[3,2]
    J_se.16.fn<-J.se[4,2]
    J_se.16.fw<-J.se[5,2]
    J_se.17.rf<-J.se[1,3]
    J_se.17.cn<-J.se[2,3]
    J_se.17.cw<-J.se[3,3]
    J_se.17.fn<-J.se[4,3]
    J_se.17.fw<-J.se[5,3]
    
par(cex.main = 1.5, mar = c(5, 4, 4, 1) + 0.1, mgp = c(3.5, 1, 0), cex.lab = 1.5, 
        font.lab = 2, cex.axis = 1.3, bty = "n", las = 1)
    x1 <- c(1, 2, 3, 4)
plot(x1, c(-10, -10, -10, -10), type = "p", ylab = "", xlab = " ", cex = 1.5, 
         ylim = c(0, 1), xlim = c(1, 4), lwd = 2, pch = 5, axes = F, main = "")  #Diversity
    axis(1, at = c(1.5, 2.5, 3.5), labels = c("2015", "2016", "2017"))
    mtext("Year", side = 1, line = 3, cex = 1.5, font = 2)
    axis(2, pos = 1.2, seq(0,1,by=0.2), las=1)
    par(las = 0)
    mtext("Evenness (J')", side = 2, line = 1.5, cex = 1.5, font = 2)
    x <- c(1.5, 2.5, 3.5)
    
    points(x, c(J_m.15.rf, J_m.16.rf, J_m.17.rf), cex = 2, lwd = 2, pch = 10)
    points(x+0.12, c(J_m.15.cn, J_m.16.cn, J_m.17.cn), cex = 2, lwd = 2, pch = 24) #,col = colors()[c(593)]
    points(x+0.06, c(J_m.15.cw, J_m.16.cw, J_m.17.cw), cex = 2, lwd = 2, pch = 17) #,col=colors()[c(593)]
    points(x-0.12, c(J_m.15.fn, J_m.16.fn, J_m.17.fn), cex = 2, lwd = 2, pch = 23) #, col=colors()[c(55)]
    points(x-0.06, c(J_m.15.fw, J_m.16.fw, J_m.17.fw), cex = 2, lwd = 2, pch = 18) #, col=colors()[c(55)]
    
    lines(x, c(J_m.15.rf, J_m.16.rf, J_m.17.rf), lwd = 4, type = "c", lty=1, col=colors()[c(320)])
    lines(x+0.12, c(J_m.15.cn, J_m.16.cn, J_m.17.cn), lwd = 4, type = "c", lty=1) #,col=colors()[c(593)]
    lines(x+0.06, c(J_m.15.cw, J_m.16.cw, J_m.17.cw), lwd = 4, type = "c", lty=2) #,col=colors()[c(593)]
    lines(x-0.12, c(J_m.15.fn, J_m.16.fn, J_m.17.fn), lwd = 4, type = "c", lty=2) #, col=colors()[c(55)]
    lines(x-0.06, c(J_m.15.fw, J_m.16.fw, J_m.17.fw), lwd = 4, type = "c",lty=1) #, col=colors()[c(55)]
    
    plot.errbars <- plotsegraph(x, c(J_m.15.rf, J_m.16.rf, J_m.17.rf), 
                                c(J_se.15.rf, J_se.16.rf, J_se.17.rf), 0.1, color = "black")  #0.1 = wiskwidth
    plot.errbars <- plotsegraph(x+0.12, c(J_m.15.cn, J_m.16.cn, J_m.17.cn), 
                                c(J_se.15.cn, J_se.16.cn, J_se.17.cn), 0.1, color = "black")  #0.1 = wiskwidth
    plot.errbars <- plotsegraph(x+0.06, c(J_m.15.cw, J_m.16.cw, J_m.17.cw), 
                                c(J_se.15.cw, J_se.16.cw, J_se.17.cw), 0.1, color = "black")  #0.1 = wiskwidth
    plot.errbars <- plotsegraph(x-0.12, c(J_m.15.fn, J_m.16.fn, J_m.17.fn), 
                                c(J_se.15.fn, J_se.16.fn, J_se.17.fn), 0.1, color = "black")  #0.1 = wiskwidth
    plot.errbars <- plotsegraph(x-0.06, c(J_m.15.fw, J_m.16.fw, J_m.17.fw), 
                                c(J_se.15.fw, J_se.16.fw, J_se.17.fw), 0.1, color = "black")  #0.1 = wiskwidth
    
    #legend("topleft", pch=c(1,2,17,5,18), inset = c(0.2,0.1), col=colors()[c(24,593,593,55,55)],
    #      lty=c(1,1,2,2,1),
    #    legend=c("Reference","Cut w/o mulch", "Cut w/ mulch","Fecon w/o mulch", "Fecon w/ mulch"))
    
    

     
attach(richness) #LMMs for richness
  lm.S<-lmer(S~Year.rel*Treatment+(Year.rel|Site:Plot)+(1|Site))
    plot(lm.S)
    hist(residuals(lm.S))
    
    summary(lm.S)
    anova(lm.S) # F (4,91) = .810 p=0.522
    #summary(glht(lm.S,contrast.matrix))
  detach(richness)  

attach(diversity) #LMMs for diversity
  lm.H<-lmer(H~Year.rel*Treatment+(Year.rel|Site:Plot)+(1|Site))
    plot(lm.H)
    hist(residuals(lm.H))
    
    summary(lm.H)
    
    anova(lm.H) # F (4,91) = 2.168 p=0.115
    
    summary(glht(lm.H,contrast.matrix))
  detach(diversity)  

attach(evenness)
  lm.J<-lmer(J~Year.rel*Treatment+(Year.rel|Site:Plot)+(1|Site))
    plot(lm.J)
    hist(residuals(lm.J))
    
    summary(lm.J)
    anova(lm.J) #Year.rel:Treatment F(4,81.3)=3.876; p=0.006
      summary(glht(lm.J,contrast.matrix)) #Cut vs Fecon different
      
    detach(evenness)
        
### summary statistics
      
t(tot.means)
t(tot.se)

t(S.means)
t(S.se)

t(H.means)
t(H.se)

t(J.means)
t(J.se)

describeBy(totals.15, totals.15$Treatment)
describeBy(totals.17, totals.15$Treatment)

###### All four figures ########
### 2x2 of all four graphs ###

#Legend function modification for multiple line/point colors
LEGEND <- function (x, y = NULL, legend, fill = NULL, 
                    col = par("col"), pt.col=col, line.col=col,
                    border = "black", lty, lwd, pch, angle = 45, density = NULL,
                    bty = "o", bg = par("bg"), box.lwd = par("lwd"), box.lty = par("lty"),
                    box.col = par("fg"), pt.bg = NA, cex = 1, pt.cex = cex, pt.lwd = lwd,
                    xjust = 0, yjust = 1, x.intersp = 1, y.intersp = 1, adj = c(0,
                                                                                0.5), text.width = NULL, text.col = par("col"), text.font = NULL,
                    merge = do.lines && has.pch, trace = FALSE, plot = TRUE,
                    ncol = 1, horiz = FALSE, title = NULL, inset = 0, xpd, title.col = text.col,
                    title.adj = 0.5, seg.len = 2)
{
  if (missing(legend) && !missing(y) && (is.character(y) ||
                                         is.expression(y))) {
    legend <- y
    y <- NULL
  }
  mfill <- !missing(fill) || !missing(density)
  if (!missing(xpd)) {
    op <- par("xpd")
    on.exit(par(xpd = op))
    par(xpd = xpd)
  }
  title <- as.graphicsAnnot(title)
  if (length(title) > 1)
    stop("invalid 'title'")
  legend <- as.graphicsAnnot(legend)
  n.leg <- if (is.call(legend))
    1
  else length(legend)
  if (n.leg == 0)
    stop("'legend' is of length 0")
  auto <- if (is.character(x))
    match.arg(x, c("bottomright", "bottom", "bottomleft",
                   "left", "topleft", "top", "topright", "right", "center"))
  else NA
  if (is.na(auto)) {
    xy <- xy.coords(x, y)
    x <- xy$x
    y <- xy$y
    nx <- length(x)
    if (nx < 1 || nx > 2)
      stop("invalid coordinate lengths")
  }
  else nx <- 0
  xlog <- par("xlog")
  ylog <- par("ylog")
  rect2 <- function(left, top, dx, dy, density = NULL, angle,
                    ...) {
    r <- left + dx
    if (xlog) {
      left <- 10^left
      r <- 10^r
    }
    b <- top - dy
    if (ylog) {
      top <- 10^top
      b <- 10^b
    }
    rect(left, top, r, b, angle = angle, density = density,
         ...)
  }
  segments2 <- function(x1, y1, dx, dy, ...) {
    x2 <- x1 + dx
    if (xlog) {
      x1 <- 10^x1
      x2 <- 10^x2
    }
    y2 <- y1 + dy
    if (ylog) {
      y1 <- 10^y1
      y2 <- 10^y2
    }
    segments(x1, y1, x2, y2, ...)
  }
  points2 <- function(x, y, ...) {
    if (xlog)
      x <- 10^x
    if (ylog)
      y <- 10^y
    points(x, y, ...)
  }
  text2 <- function(x, y, ...) {
    if (xlog)
      x <- 10^x
    if (ylog)
      y <- 10^y
    text(x, y, ...)
  }
  if (trace)
    catn <- function(...) do.call("cat", c(lapply(list(...),
                                                  formatC), list("\n")))
  cin <- par("cin")
  Cex <- cex * par("cex")
  if (is.null(text.width))
    text.width <- max(abs(strwidth(legend, units = "user",
                                   cex = cex, font = text.font)))
  else if (!is.numeric(text.width) || text.width < 0)
    stop("'text.width' must be numeric, >= 0")
  xc <- Cex * xinch(cin[1L], warn.log = FALSE)
  yc <- Cex * yinch(cin[2L], warn.log = FALSE)
  if (xc < 0)
    text.width <- -text.width
  xchar <- xc
  xextra <- 0
  yextra <- yc * (y.intersp - 1)
  ymax <- yc * max(1, strheight(legend, units = "user", cex = cex)/yc)
  ychar <- yextra + ymax
  if (trace)
    catn("  xchar=", xchar, "; (yextra,ychar)=", c(yextra,
                                                   ychar))
  if (mfill) {
    xbox <- xc * 0.8
    ybox <- yc * 0.5
    dx.fill <- xbox
  }
  do.lines <- (!missing(lty) && (is.character(lty) || any(lty >
                                                            0))) || !missing(lwd)
  n.legpercol <- if (horiz) {
    if (ncol != 1)
      warning(gettextf("horizontal specification overrides: Number of columns := %d",
                       n.leg), domain = NA)
    ncol <- n.leg
    1
  }
  else ceiling(n.leg/ncol)
  has.pch <- !missing(pch) && length(pch) > 0
  if (do.lines) {
    x.off <- if (merge)
      -0.7
    else 0
  }
  else if (merge)
    warning("'merge = TRUE' has no effect when no line segments are drawn")
  if (has.pch) {
    if (is.character(pch) && !is.na(pch[1L]) && nchar(pch[1L],
                                                      type = "c") > 1) {
      if (length(pch) > 1)
        warning("not using pch[2..] since pch[1L] has multiple chars")
      np <- nchar(pch[1L], type = "c")
      pch <- substr(rep.int(pch[1L], np), 1L:np, 1L:np)
    }
    if (!is.character(pch))
      pch <- as.integer(pch)
  }
  if (is.na(auto)) {
    if (xlog)
      x <- log10(x)
    if (ylog)
      y <- log10(y)
  }
  if (nx == 2) {
    x <- sort(x)
    y <- sort(y)
    left <- x[1L]
    top <- y[2L]
    w <- diff(x)
    h <- diff(y)
    w0 <- w/ncol
    x <- mean(x)
    y <- mean(y)
    if (missing(xjust))
      xjust <- 0.5
    if (missing(yjust))
      yjust <- 0.5
  }
  else {
    h <- (n.legpercol + (!is.null(title))) * ychar + yc
    w0 <- text.width + (x.intersp + 1) * xchar
    if (mfill)
      w0 <- w0 + dx.fill
    if (do.lines)
      w0 <- w0 + (seg.len + x.off) * xchar
    w <- ncol * w0 + 0.5 * xchar
    if (!is.null(title) && (abs(tw <- strwidth(title, units = "user",
                                               cex = cex) + 0.5 * xchar)) > abs(w)) {
      xextra <- (tw - w)/2
      w <- tw
    }
    if (is.na(auto)) {
      left <- x - xjust * w
      top <- y + (1 - yjust) * h
    }
    else {
      usr <- par("usr")
      inset <- rep_len(inset, 2)
      insetx <- inset[1L] * (usr[2L] - usr[1L])
      left <- switch(auto, bottomright = , topright = ,
                     right = usr[2L] - w - insetx, bottomleft = ,
                     left = , topleft = usr[1L] + insetx, bottom = ,
                     top = , center = (usr[1L] + usr[2L] - w)/2)
      insety <- inset[2L] * (usr[4L] - usr[3L])
      top <- switch(auto, bottomright = , bottom = , bottomleft = usr[3L] +
                      h + insety, topleft = , top = , topright = usr[4L] -
                      insety, left = , right = , center = (usr[3L] +
                                                             usr[4L] + h)/2)
    }
  }
  if (plot && bty != "n") {
    if (trace)
      catn("  rect2(", left, ",", top, ", w=", w, ", h=",
           h, ", ...)", sep = "")
    rect2(left, top, dx = w, dy = h, col = bg, density = NULL,
          lwd = box.lwd, lty = box.lty, border = box.col)
  }
  xt <- left + xchar + xextra + (w0 * rep.int(0:(ncol - 1),
                                              rep.int(n.legpercol, ncol)))[1L:n.leg]
  yt <- top - 0.5 * yextra - ymax - (rep.int(1L:n.legpercol,
                                             ncol)[1L:n.leg] - 1 + (!is.null(title))) * ychar
  if (mfill) {
    if (plot) {
      if (!is.null(fill))
        fill <- rep_len(fill, n.leg)
      rect2(left = xt, top = yt + ybox/2, dx = xbox, dy = ybox,
            col = fill, density = density, angle = angle,
            border = border)
    }
    xt <- xt + dx.fill
  }
  if (plot && (has.pch || do.lines)) {
    pt.COL <- rep_len(pt.col, n.leg)
    line.COL <- rep_len(line.col, n.leg)
  }
  if (missing(lwd) || is.null(lwd))
    lwd <- par("lwd")
  if (do.lines) {
    if (missing(lty) || is.null(lty))
      lty <- 1
    lty <- rep_len(lty, n.leg)
    lwd <- rep_len(lwd, n.leg)
    ok.l <- !is.na(lty) & (is.character(lty) | lty > 0) &
      !is.na(lwd)
    if (trace)
      catn("  segments2(", xt[ok.l] + x.off * xchar, ",",
           yt[ok.l], ", dx=", seg.len * xchar, ", dy=0, ...)")
    if (plot)
      segments2(xt[ok.l] + x.off * xchar, yt[ok.l], dx = seg.len *
                  xchar, dy = 0, lty = lty[ok.l], lwd = lwd[ok.l],
                col = line.COL[ok.l])
    xt <- xt + (seg.len + x.off) * xchar
  }
  if (has.pch) {
    pch <- rep_len(pch, n.leg)
    pt.bg <- rep_len(pt.bg, n.leg)
    pt.cex <- rep_len(pt.cex, n.leg)
    pt.lwd <- rep_len(pt.lwd, n.leg)
    ok <- !is.na(pch)
    if (!is.character(pch)) {
      ok <- ok & (pch >= 0 | pch <= -32)
    }
    else {
      ok <- ok & nzchar(pch)
    }
    x1 <- (if (merge && do.lines)
      xt - (seg.len/2) * xchar
      else xt)[ok]
    y1 <- yt[ok]
    if (trace)
      catn("  points2(", x1, ",", y1, ", pch=", pch[ok],
           ", ...)")
    if (plot)
      points2(x1, y1, pch = pch[ok], col = pt.COL[ok], cex = pt.cex[ok],
              bg = pt.bg[ok], lwd = pt.lwd[ok])
  }
  xt <- xt + x.intersp * xchar
  if (plot) {
    if (!is.null(title))
      text2(left + w * title.adj, top - ymax, labels = title,
            adj = c(title.adj, 0), cex = cex, col = title.col)
    text2(xt, yt, labels = legend, adj = adj, cex = cex,
          col = text.col, font = text.font)
  }
  invisible(list(rect = list(w = w, h = h, left = left, top = top),
                 text = list(x = xt, y = yt)))
}

#### Plot Start ####
setwd("~/Library/Mobile Documents/com~apple~CloudDocs/Purdue PC/Honeysuckle Project/Forests Submission/Figures")

tiff("Fig. 5_Spring Ephemeral Abundance and Diversity.tiff", height = 7.5, width = 6, units = "in", compression = "lzw", res = 400, pointsize = 11, bg = NA)  
m <- matrix(c(1,2,3,4,5,6),nrow = 3,ncol = 2,byrow = TRUE)

layout(mat = m,heights = c(1,1,1,1,0.5,0.5))


par(cex.main = 1.5, mar = c(4, 4, 3, 0) + 0.1, mgp = c(3.5, 1, 0), cex.lab = 1.3, 
    font.lab = 2, cex.axis = 1, bty = "n", las = 1)

x1 <- c(1, 2, 3, 4)
plot(x1, c(-10, -10, -10, -10), type = "p", ylab = "", xlab = " ", cex = 1.5, 
     ylim = c(0, 7), xlim = c(1, 4), lwd = 1, pch = 5, axes = F, main = "")  #Total Spring Ephemeral Cover
axis(1, at = c(1.5, 2.5, 3.5), labels = c("2015", "2016", "2017"))
#mtext("Year", side = 1, line = 3.2, cex = 1, font = 1)
axis(2, pos = 1.2, seq(0,7,by=1), las=1)
par(las = 0)
mtext(expression("Percent Cover"), las=0,side = 2, line = 1.5, cex = 1, font = 1)
mtext("(a)",side = 3,line=1.5,cex=1,font=1, adj = 0)

x <- c(1.5, 2.5, 3.5)

plot.errbars <- plotsegraph(x, c(m.15.rf, m.16.rf, m.17.rf), 
                            c(se.15.rf, se.16.rf, se.17.rf), 0.07, color = "black")  #0.1 = wiskwidth
plot.errbars <- plotsegraph(x+0.12, c(m.15.cn, m.16.cn, m.17.cn), 
                            c(se.15.cn, se.16.cn, se.17.cn), 0.07, color = "black")  #0.1 = wiskwidth
plot.errbars <- plotsegraph(x+0.06, c(m.15.cw, m.16.cw, m.17.cw), 
                            c(se.15.cw, se.16.cw, se.17.cw), 0.07, color = "black")  #0.1 = wiskwidth
plot.errbars <- plotsegraph(x-0.12, c(m.15.fn, m.16.fn, m.17.fn), 
                            c(se.15.fn, se.16.fn, se.17.fn), 0.07, color = "black")  #0.1 = wiskwidth
plot.errbars <- plotsegraph(x-0.06, c(m.15.fw, m.16.fw, m.17.fw), 
                            c(se.15.fw, se.16.fw, se.17.fw), 0.07, color = "black")  #0.1 = wiskwidth

lines(x,      c(m.15.rf, m.16.rf, m.17.rf), lwd = 1, type = "c", lty=1,col=colors()[c(320)])
lines(x+0.12, c(m.15.cn, m.16.cn, m.17.cn), lwd = 1, type = "c", lty=1, col = "royalblue3")
lines(x+0.06, c(m.15.cw, m.16.cw, m.17.cw), lwd = 1, type = "c", lty=2, col = "royalblue3")
lines(x-0.12, c(m.15.fn, m.16.fn, m.17.fn), lwd = 1, type = "c", lty=2, col = "darkorange")
lines(x-0.06, c(m.15.fw, m.16.fw, m.17.fw), lwd = 1, type = "c", lty=1, col = "darkorange")

points(x,      c(m.15.rf, m.16.rf, m.17.rf), cex = 1.8, lwd = 1, pch = 10)
points(x+0.12, c(m.15.cn, m.16.cn, m.17.cn), cex = 1.8, lwd = 1, pch = 24, col = "royalblue3", bg = "white")
points(x+0.06, c(m.15.cw, m.16.cw, m.17.cw), cex = 1.8, lwd = 1, pch = 17, col = "royalblue3")
points(x-0.12, c(m.15.fn, m.16.fn, m.17.fn), cex = 1.8, lwd = 1, pch = 23, col = "darkorange", bg = "white")
points(x-0.06, c(m.15.fw, m.16.fw, m.17.fw), cex = 1.8, lwd = 1, pch = 18, col = "darkorange")

### Richness

x1 <- c(1, 2, 3, 4)
plot(x1, c(-10, -10, -10, -10), type = "p", ylab = "", xlab = " ", cex = 1.5, 
     ylim = c(0, 6), xlim = c(1, 4), lwd = 2, pch = 5, axes = F, main = "")  #Richness
axis(1, at = c(1.5, 2.5, 3.5), labels = c("2015", "2016", "2017"))
#mtext("Year", side = 1, line = 3.2, cex = 1, font = 1)
axis(2, pos = 1.2, seq(0,6,by=1), las=1)
par(las = 0)
mtext(expression("Richness (S)"), side = 2, line = 1.5, cex = 1, font = 1)
mtext("(b)",side = 3,line=1.5,cex=1,font=1, adj = 0)

x <- c(1.5, 2.5, 3.5)

plot.errbars <- plotsegraph(x, c(S_m.15.rf, S_m.16.rf, S_m.17.rf), 
                            c(S_se.15.rf, S_se.16.rf, S_se.17.rf), 0.07, color = "black")  #0.1 = wiskwidth
plot.errbars <- plotsegraph(x+0.12, c(S_m.15.cn, S_m.16.cn, S_m.17.cn), 
                            c(S_se.15.cn, S_se.16.cn, S_se.17.cn), 0.07, color = "black")  #0.1 = wiskwidth
plot.errbars <- plotsegraph(x+0.06, c(S_m.15.cw, S_m.16.cw, S_m.17.cw), 
                            c(S_se.15.cw, S_se.16.cw, S_se.17.cw), 0.07, color = "black")  #0.1 = wiskwidth
plot.errbars <- plotsegraph(x-0.12, c(S_m.15.fn, S_m.16.fn, S_m.17.fn), 
                            c(S_se.15.fn, S_se.16.fn, S_se.17.fn), 0.07, color = "black")  #0.1 = wiskwidth
plot.errbars <- plotsegraph(x-0.06, c(S_m.15.fw, S_m.16.fw, S_m.17.fw), 
                            c(S_se.15.fw, S_se.16.fw, S_se.17.fw), 0.07, color = "black")  #0.1 = wiskwidth

lines(x,      c(S_m.15.rf, S_m.16.rf, S_m.17.rf), lwd = 1, type = "c", lty=1,col=colors()[c(320)])
lines(x+0.12, c(S_m.15.cn, S_m.16.cn, S_m.17.cn), lwd = 1, type = "c", lty=1, col = "royalblue3")
lines(x+0.06, c(S_m.15.cw, S_m.16.cw, S_m.17.cw), lwd = 1, type = "c", lty=2, col = "royalblue3")
lines(x-0.12, c(S_m.15.fn, S_m.16.fn, S_m.17.fn), lwd = 1, type = "c", lty=2, col = "darkorange")
lines(x-0.06, c(S_m.15.fw, S_m.16.fw, S_m.17.fw), lwd = 1, type = "c", lty=1, col = "darkorange")

points(x,      c(S_m.15.rf, S_m.16.rf, S_m.17.rf), cex = 1.8, lwd = 1, pch = 10)
points(x+0.12, c(S_m.15.cn, S_m.16.cn, S_m.17.cn), cex = 1.8, lwd = 1, pch = 24, col = "royalblue3", bg = "white")
points(x+0.06, c(S_m.15.cw, S_m.16.cw, S_m.17.cw), cex = 1.8, lwd = 1, pch = 17, col = "royalblue3")
points(x-0.12, c(S_m.15.fn, S_m.16.fn, S_m.17.fn), cex = 1.8, lwd = 1, pch = 23, col = "darkorange", bg = "white")
points(x-0.06, c(S_m.15.fw, S_m.16.fw, S_m.17.fw), cex = 1.8, lwd = 1, pch = 18, col = "darkorange")

#### Diversity linegraph

x1 <- c(1, 2, 3, 4)
plot(x1, c(-10, -10, -10, -10), type = "p", ylab = "", xlab = " ", cex = 1.5, 
     ylim = c(0, 1.2), xlim = c(1, 4), lwd = 1, pch = 5, axes = F, main = "")  #Richness
axis(1, at = c(1.5, 2.5, 3.5), labels = c("2015", "2016", "2017"))
#mtext("Year", side = 1, line = 3.2, cex = 1, font = 1)
axis(2, pos = 1.2, seq(0,1.2,by=0.2), las=1)
par(las = 0)
mtext(expression("Diversity (H')"), side = 2, line = 1.5, cex = 1, font = 1)
mtext("(c)",side = 3,line=1.5,cex=1,font=1, adj = 0)

x <- c(1.5, 2.5, 3.5)

plot.errbars <- plotsegraph(x, c(H_m.15.rf, H_m.16.rf, H_m.17.rf), 
                            c(H_se.15.rf, H_se.16.rf, H_se.17.rf), 0.07, color = "black")  #0.1 = wiskwidth
plot.errbars <- plotsegraph(x+0.12, c(H_m.15.cn, H_m.16.cn, H_m.17.cn), 
                            c(H_se.15.cn, H_se.16.cn, H_se.17.cn), 0.07, color = "black")  #0.1 = wiskwidth
plot.errbars <- plotsegraph(x+0.06, c(H_m.15.cw, H_m.16.cw, H_m.17.cw), 
                            c(H_se.15.cw, H_se.16.cw, H_se.17.cw), 0.07, color = "black")  #0.1 = wiskwidth
plot.errbars <- plotsegraph(x-0.12, c(H_m.15.fn, H_m.16.fn, H_m.17.fn), 
                            c(H_se.15.fn, H_se.16.fn, H_se.17.fn), 0.07, color = "black")  #0.1 = wiskwidth
plot.errbars <- plotsegraph(x-0.06, c(H_m.15.fw, H_m.16.fw, H_m.17.fw), 
                            c(H_se.15.fw, H_se.16.fw, H_se.17.fw), 0.07, color = "black")  #0.1 = wiskwidth

lines(x,      c(H_m.15.rf, H_m.16.rf, H_m.17.rf), lwd = 1, type = "c", lty=1,col=colors()[c(320)])
lines(x+0.12, c(H_m.15.cn, H_m.16.cn, H_m.17.cn), lwd = 1, type = "c", lty=1, col = "royalblue3")
lines(x+0.06, c(H_m.15.cw, H_m.16.cw, H_m.17.cw), lwd = 1, type = "c", lty=2, col = "royalblue3")
lines(x-0.12, c(H_m.15.fn, H_m.16.fn, H_m.17.fn), lwd = 1, type = "c", lty=2, col = "darkorange")
lines(x-0.06, c(H_m.15.fw, H_m.16.fw, H_m.17.fw), lwd = 1, type = "c", lty=1, col = "darkorange")

points(x,      c(H_m.15.rf, H_m.16.rf, H_m.17.rf), cex = 1.8, lwd = 1, pch = 10)
points(x+0.12, c(H_m.15.cn, H_m.16.cn, H_m.17.cn), cex = 1.8, lwd = 1, pch = 24, col = "royalblue3", bg = "white")
points(x+0.06, c(H_m.15.cw, H_m.16.cw, H_m.17.cw), cex = 1.8, lwd = 1, pch = 17, col = "royalblue3")
points(x-0.12, c(H_m.15.fn, H_m.16.fn, H_m.17.fn), cex = 1.8, lwd = 1, pch = 23, col = "darkorange", bg = "white")
points(x-0.06, c(H_m.15.fw, H_m.16.fw, H_m.17.fw), cex = 1.8, lwd = 1, pch = 18, col = "darkorange")

### Evenness linegraph

x1 <- c(1, 2, 3, 4)
plot(x1, c(-10, -10, -10, -10), type = "p", ylab = "", xlab = " ", cex = 1.5, 
     ylim = c(0, 1), xlim = c(1, 4), lwd = 2, pch = 5, axes = F, main = "")  
axis(1, at = c(1.5, 2.5, 3.5), labels = c("2015", "2016", "2017"))
#mtext("Year", side = 1, line = 3.2, cex = 1, font = 1)
axis(2, pos = 1.2, seq(0,1,by=0.2), las=1)
par(las = 0)
mtext(expression("Evenness (J')"), side = 2, line = 1.5, cex = 1, font = 1)
mtext("(d)",side = 3,line=1.5,cex=1,font=1, adj = 0)

x <- c(1.5, 2.5, 3.5)

plot.errbars <- plotsegraph(x, c(J_m.15.rf, J_m.16.rf, J_m.17.rf), 
                            c(J_se.15.rf, J_se.16.rf, J_se.17.rf), 0.07, color = "black")  #0.1 = wiskwidth
plot.errbars <- plotsegraph(x+0.12, c(J_m.15.cn, J_m.16.cn, J_m.17.cn), 
                            c(J_se.15.cn, J_se.16.cn, J_se.17.cn), 0.07, color = "black")  #0.1 = wiskwidth
plot.errbars <- plotsegraph(x+0.06, c(J_m.15.cw, J_m.16.cw, J_m.17.cw), 
                            c(J_se.15.cw, J_se.16.cw, J_se.17.cw), 0.07, color = "black")  #0.1 = wiskwidth
plot.errbars <- plotsegraph(x-0.12, c(J_m.15.fn, J_m.16.fn, J_m.17.fn), 
                            c(J_se.15.fn, J_se.16.fn, J_se.17.fn), 0.07, color = "black")  #0.1 = wiskwidth
plot.errbars <- plotsegraph(x-0.06, c(J_m.15.fw, J_m.16.fw, J_m.17.fw), 
                            c(J_se.15.fw, J_se.16.fw, J_se.17.fw), 0.07, color = "black")  #0.1 = wiskwidth

lines(x,      c(J_m.15.rf, J_m.16.rf, J_m.17.rf), lwd = 1, type = "c", lty=1, col=colors()[c(320)])
lines(x+0.12, c(J_m.15.cn, J_m.16.cn, J_m.17.cn), lwd = 1, type = "c", lty=1, col = "royalblue3")
lines(x+0.06, c(J_m.15.cw, J_m.16.cw, J_m.17.cw), lwd = 1, type = "c", lty=2, col = "royalblue3")
lines(x-0.12, c(J_m.15.fn, J_m.16.fn, J_m.17.fn), lwd = 1, type = "c", lty=2, col = "darkorange")
lines(x-0.06, c(J_m.15.fw, J_m.16.fw, J_m.17.fw), lwd = 1, type = "c", lty=1, col = "darkorange")

points(x,      c(J_m.15.rf, J_m.16.rf, J_m.17.rf), cex = 1.8, lwd = 1, pch = 10)
points(x+0.12, c(J_m.15.cn, J_m.16.cn, J_m.17.cn), cex = 1.8, lwd = 1, pch = 24, col = "royalblue3", bg = "white")
points(x+0.06, c(J_m.15.cw, J_m.16.cw, J_m.17.cw), cex = 1.8, lwd = 1, pch = 17, col = "royalblue3")
points(x-0.12, c(J_m.15.fn, J_m.16.fn, J_m.17.fn), cex = 1.8, lwd = 1, pch = 23, col = "darkorange", bg = "white")
points(x-0.06, c(J_m.15.fw, J_m.16.fw, J_m.17.fw), cex = 1.8, lwd = 1, pch = 18, col = "darkorange")

par(mar=c(5,5,0,1)+0.1)
plot(1,type="n",axes = F,xlab="",ylab="")
LEGEND("topleft",pch=c(24,17,10), lty=c(1,2,1), col=c("royalblue3","royalblue3",colors()[(320)]),pt.bg="white",pt.col=c("royalblue3","royalblue3",1),pt.cex=2,lwd=1,seg.len=4,bty = "n", cex=1.3, ncol=1,
       pt.lwd=1,y.intersp=1.3,x.intersp=0.2,legend = c("Cut-stump w/out mulch","Cut-stump w/ mulch", "Reference"))
plot(1,type="n",axes = F,xlab="",ylab="")
LEGEND("topleft",pch=c(23,18), lty=c(2,1), col="darkorange",pt.bg="white",pt.col="darkorange",pt.cex=2,lwd=1,seg.len=4,bty = "n", cex=1.3, ncol=1,
       pt.lwd=1,y.intersp=1.3,x.intersp=0.2,legend = c("MH w/out mulch","MH w/ mulch"))

dev.off()
